@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.005004'; # VERSION
+our $VERSION = '0.006000'; # VERSION
 
 use Moose;
 extends 'Business::CyberSource::Factory';
@@ -26,15 +26,13 @@ use Exception::Base (
 	ignore_package => [ __PACKAGE__, 'Business::CyberSource::Client' ],
 );
 
-
 sub create {
 	my ( $self, $dto, $answer ) = @_;
 
-	my $result = $self->_get_result( $dto, $answer );
+	my $result = $answer->{result};
 
 	my $decision = $self->_get_decision( $result );
 
-
 	# the reply is a subsection of result named after the specic request, e.g
 	# ccAuthReply
 	my $reply = $self->_get_reply( $result );
@@ -177,6 +175,7 @@ sub _get_reply {
 
 sub _get_decision {
 	my ( $self, $result ) = @_;
+
 	my $_;
 
 	my ( $decision )
@@ -193,27 +192,6 @@ sub _get_decision {
 	return $decision;
 }
 
-sub _get_result {
-	my ( $self, $dto, $answer ) = @_;
-
-	return $answer->{result} if $answer->{result};
-
-		Business::CyberSource::Exception->throw(
-				message => 'answer not defined and not skipable'
-			)
-			unless $dto->is_skipable
-			;
-
-		# right now the only reason to do this expired card
-		return {
-			merchantReferenceCode => $dto->reference_code,
-			decision              => 'REJECT',
-			reasonCode            => '202',
-			requestID             => 0,
-			requestToken          => 0,
-		};
-}
-
 1;
 
 # ABSTRACT: A Response Factory
@@ -228,7 +206,7 @@ Business::CyberSource::Factory::Response - A Response Factory
 
 =head1 VERSION
 
-version 0.005004
+version 0.006000
 
 =head1 METHODS
 
