@@ -3,23 +3,19 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.005004'; # VERSION
+our $VERSION = '0.006000'; # VERSION
 
 use Moose;
 extends 'Business::CyberSource::Request';
 with qw(
-	Business::CyberSource::Request::Role::Common
 	Business::CyberSource::Request::Role::BillingInfo
-	Business::CyberSource::Request::Role::PurchaseInfo
 	Business::CyberSource::Request::Role::CreditCardInfo
 	Business::CyberSource::Request::Role::BusinessRules
 	Business::CyberSource::Request::Role::DCC
+	Business::CyberSource::Request::Role::TaxService
 );
 
-before serialize => sub {
-	my $self = shift;
-	$self->_request_data->{ccAuthService}{run} = 'true';
-};
+has '+service' => ( remote_name => 'ccAuthService' );
 
 __PACKAGE__->meta->make_immutable;
 1;
@@ -36,7 +32,36 @@ Business::CyberSource::Request::Authorization - CyberSource Authorization Reques
 
 =head1 VERSION
 
-version 0.005004
+version 0.006000
+
+=head1 SYNOPSIS
+
+	use Business::CyberSource::Request::Authorization;
+
+	Business::CyberSource::Request::Authorization->new({
+		reference_code => '42',
+		bill_to => {
+			first_name  => 'Caleb',
+			last_name   => 'Cushing',
+			street      => '100 somewhere st',
+			city        => 'Houston',
+			state       => 'TX',
+			postal_code => '77064',
+			country     => 'US',
+			email       => 'xenoterracide@gmail.com',
+		},
+		purchase_totals => {
+			currency => 'USD',
+			total    => 5.00,
+		},
+		card => {
+			account_number => '4111111111111111',
+			expiration => {
+				month => 9,
+				year  => 2025,
+			},
+		},
+	});
 
 =head1 DESCRIPTION
 
@@ -47,18 +72,16 @@ you receive this payment confirmation. For offline credit cards, it will take
 typically five days longer to receive payment confirmation than for online
 cards.
 
-=head2 inherits
+=head1 EXTENDS
 
 L<Business::CyberSource::Request>
 
-=head2 composes
+=head1 WITH
 
 =over
 
 =item L<Business::CyberSource::Request::Role::BillingInfo>
 
-=item L<Business::CyberSource::Request::Role::PurchaseInfo>
-
 =item L<Business::CyberSource::Request::Role::CreditCardInfo>
 
 =item L<Business::CyberSource::Request::Role::BusinessRules>
@@ -67,6 +90,8 @@ L<Business::CyberSource::Request>
 
 =back
 
+=for Pod::Coverage BUILD
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
