@@ -3,24 +3,22 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.005004'; # VERSION
+our $VERSION = '0.006000'; # VERSION
 
 use Moose;
 extends 'Business::CyberSource::Request';
 with qw(
-	Business::CyberSource::Request::Role::Common
-	Business::CyberSource::Request::Role::FollowUp
 	Business::CyberSource::Request::Role::DCC
+	Business::CyberSource::Request::Role::TaxService
 );
 
-before serialize => sub {
-	my $self = shift;
+use MooseX::Types::CyberSource qw( CaptureService );
 
-	$self->_request_data->{ccCaptureService}{run} = 'true';
-	$self->_request_data->{ccCaptureService}{authRequestID}
-		= $self->request_id
-		;
-};
+has '+service' => (
+	isa         => CaptureService,
+	remote_name => 'ccCaptureService',
+	lazy_build  => 0,
+);
 
 __PACKAGE__->meta->make_immutable;
 1;
@@ -37,31 +35,35 @@ Business::CyberSource::Request::Capture - CyberSource Capture Request Object
 
 =head1 VERSION
 
-version 0.005004
+version 0.006000
 
 =head1 SYNOPSIS
 
+	use Business::CyberSource::Request::Capture;
+
 	my $capture = Business::CyberSource::Request::Capture->new({
 		reference_code => 'merchant reference code',
-		request_id     => 'authorization response request_id',
-		total          => 5.01,  # same amount as in authorization
-		currency       => 'USD', # same currency as in authorization
+		service => {
+			request_id => 'authorization response request_id',
+		},
+		purchase_totals => {
+			total    => 5.01,  # same amount as in authorization
+			currency => 'USD', # same currency as in authorization
+		},
 	});
 
 =head1 DESCRIPTION
 
 This object allows you to create a request for a capture.
 
-=head2 inherits
+=head1 EXTENDS
 
 L<Business::CyberSource::Request>
 
-=head2 composes
+=head1 WITH
 
 =over
 
-=item L<Business::CyberSource::Request::Role::FollowUp>
-
 =item L<Business::CyberSource::Request::Role::DCC>
 
 =back
