@@ -3,21 +3,17 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.005004'; # VERSION
+our $VERSION = '0.006000'; # VERSION
 
 use Moose;
 extends 'Business::CyberSource::Request';
 with qw(
-	Business::CyberSource::Request::Role::Common
-	Business::CyberSource::Request::Role::PurchaseInfo
 	Business::CyberSource::Request::Role::CreditCardInfo
 	Business::CyberSource::Role::ForeignCurrency
+	Business::CyberSource::Request::Role::TaxService
 );
 
-before serialize => sub {
-	my $self = shift;
-	$self->_request_data->{ccDCCService}{run} = 'true';
-};
+has '+service' => ( remote_name => 'ccDCCService' );
 
 __PACKAGE__->meta->make_immutable;
 1;
@@ -34,7 +30,7 @@ Business::CyberSource::Request::DCC - CyberSource DCC Request Object
 
 =head1 VERSION
 
-version 0.005004
+version 0.006000
 
 =head1 SYNOPSIS
 
@@ -43,28 +39,32 @@ version 0.005004
 	my $dcc
 		= Business::CyberSource::Request::DCC->new({
 			reference_code => '1984',
-			currency       => 'USD',
-			credit_card    => '5100870000000004',
-			cc_exp_month   => '04',
-			cc_exp_year    => '2012',
-			total          => '1.00',
-			foreign_currency => 'EUR',
+			purchase_totals => {
+				currency       => 'USD',
+				total          => '1.00',
+				foreign_currency => 'EUR',
+			},
+			card => {
+				credit_card    => '5100870000000004',
+				expiration => {
+					month => '04',
+					year  => '2012',
+				},
+			},
 		});
 
 =head1 DESCRIPTION
 
 This object allows you to create a request for Direct Currency Conversion.
 
-=head2 inherits
+=head1 EXTENDS
 
 L<Business::CyberSource::Request>
 
-=head2 composes
+=head1 WITH
 
 =over
 
-=item L<Business::CyberSource::Request::Role::PurchaseInfo>
-
 =item L<Business::CyberSource::Request::Role::CreditCardInfo>
 
 =item L<Business::CyberSource::Role::ForeignCurrency>
