@@ -3,13 +3,17 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.005004'; # VERSION
+our $VERSION = '0.006000'; # VERSION
 
 use Moose;
 extends 'Business::CyberSource::Request::Credit';
-with qw(
-	Business::CyberSource::Request::Role::FollowUp
-);
+
+sub BUILD { ## no critic ( Subroutines::RequireFinalReturn )
+	my $self = shift;
+	confess 'a Follow On Credit should set a request_id'
+		unless $self->service->has_request_id
+		;
+};
 
 __PACKAGE__->meta->make_immutable;
 1;
@@ -26,7 +30,7 @@ Business::CyberSource::Request::FollowOnCredit - CyberSource Credit Request Obje
 
 =head1 VERSION
 
-version 0.005004
+version 0.006000
 
 =head1 SYNOPSIS
 
@@ -34,27 +38,23 @@ version 0.005004
 
 	my $credit = Business::CyberSource::Request::FollowOnCredit->new({
 			reference_code => 'merchant reference code',
-			total          => 5.00,
-			currency       => 'USD',
-			request_id     => 'capture request_id',
+			purchase_totals => {
+				total    => 5.00,
+				currency => 'USD',
+			},
+			service => {
+				request_id => 'capture request_id',
+			},
 		});
 
 =head1 DESCRIPTION
 
 Follow-On credit Data Transfer Object.
 
-=head2 inherits
+=head2 EXTENDS
 
 L<Business::CyberSource::Request::Credit>
 
-=head2 composes
-
-=over
-
-=item L<Business::CyberSource::Request::Role::FollowUp>
-
-=back
-
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
