@@ -1,28 +1,27 @@
 package Business::CyberSource::Request::Role::DCC;
-use 5.008;
 use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.005004'; # VERSION
+our $VERSION = '0.006000'; # VERSION
 
 use Moose::Role;
+use MooseX::RemoteHelper;
 use MooseX::SetOnce 0.200001;
 
-with qw(
-	Business::CyberSource::Role::ForeignCurrency
-);
+with 'Business::CyberSource::Role::ForeignCurrency';
 
 use MooseX::Types::CyberSource qw( DCCIndicator );
 
 has dcc_indicator => (
-	isa       => DCCIndicator,
-	traits    => [ 'SetOnce' ],
-	is        => 'rw',
-	predicate => 'has_dcc_indicator',
-	trigger   => sub {
-		my $self = shift;
-		$self->_request_data->{dcc}{dccIndicator} = $self->dcc_indicator;
+	isa         => DCCIndicator,
+	remote_name => 'dcc',
+	predicate   => 'has_dcc_indicator',
+	traits      => [ 'SetOnce' ],
+	is          => 'rw',
+	serializer  => sub {
+		my ( $attr, $instance ) = @_;
+		return { dccIndicator => $attr->get_value( $instance ) };
 	},
 );
 
@@ -40,11 +39,37 @@ Business::CyberSource::Request::Role::DCC - Role for DCC follow up requests
 
 =head1 VERSION
 
-version 0.005004
+version 0.006000
 
 =head1 DESCRIPTION
 
-=head2 composes
+=head1 ATTRIBUTES
+
+=head2 dcc_indicator
+
+Flag that indicates whether DCC is being used for the transaction.
+
+This field is required if you called the DCC service for the purchase.
+
+Possible values:
+
+=over
+
+=item 1: Converted
+
+DCC is being used.
+
+=item 2: Nonconvertible
+
+DCC cannot be used.
+
+=item 3: Declined
+
+DCC could be used, but the customer declined it.
+
+=back
+
+=head1 WITH
 
 =over
 
@@ -52,10 +77,6 @@ version 0.005004
 
 =back
 
-=head1 ATTRIBUTES
-
-=head2 dcc_indicator
-
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
