@@ -3,15 +3,23 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.005004'; # VERSION
+our $VERSION = '0.006000'; # VERSION
 
 use Moose;
 extends 'Business::CyberSource::Request::Authorization';
 
-before serialize => sub {
-	my $self = shift;
-	$self->_request_data->{ccCaptureService}{run} = 'true';
-};
+use MooseX::Types::CyberSource qw( Service );
+
+has capture_service => (
+	isa      => Service,
+	remote_name => 'ccCaptureService',
+	is          => 'ro',
+	lazy        => 1,
+	coerce      => 1,
+	reader      => undef,
+	init_arg    => undef,
+	builder     => '_build_service',
+);
 
 __PACKAGE__->meta->make_immutable;
 1;
@@ -28,7 +36,7 @@ Business::CyberSource::Request::Sale - Sale Request Object
 
 =head1 VERSION
 
-version 0.005004
+version 0.006000
 
 =head1 SYNOPSIS
 
@@ -37,19 +45,27 @@ version 0.005004
 	my $req
 		= Business::CyberSource::Request::Sale->new({
 			reference_code => 't601',
-			first_name     => 'Caleb',
-			last_name      => 'Cushing',
-			street         => 'somewhere',
-			city           => 'Houston',
-			state          => 'TX',
-			zip            => '77064',
-			country        => 'US',
-			email          => 'xenoterracide@gmail.com',
-			total          => 3000.00,
-			currency       => 'USD',
-			credit_card    => '4111-1111-1111-1111',
-			cc_exp_month   => '09',
-			cc_exp_year    => '2025',
+			bill_to => {
+				first_name  => 'Caleb',
+				last_name   => 'Cushing',
+				street      => 'somewhere',
+				city        => 'Houston',
+				state       => 'TX',
+				postal_code => '77064',
+				country     => 'US',
+				email       => 'xenoterracide@gmail.com',
+			},
+			purchase_totals => {
+				total    => 3000.00,
+				currency => 'USD',
+			},
+			card => {
+				account_number => '4111-1111-1111-1111',
+				expiration     => {
+					month => 9,
+					year  => 2025,
+				},
+			},
 		});
 
 =head1 DESCRIPTION
@@ -59,7 +75,14 @@ separate authorization and capture if there is no delay between taking a
 customer's order and shipping the goods. A sale is typically used for
 electronic goods and for services that you can turn on immediately.
 
-=head2 inherits
+=head1 ATTRIBUTES
+
+=head2 capture_service
+
+Sale does both authorization and capture and so needs another service
+attribute. It is built for you and cannot be modified.
+
+=head1 EXTENDS
 
 L<Business::CyberSource::Request::Authorization>
 
