@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.005004'; # VERSION
+our $VERSION = '0.006000'; # VERSION
 
 use Moose;
 extends 'Business::CyberSource::Request::Credit';
@@ -12,6 +12,13 @@ with qw(
 	Business::CyberSource::Request::Role::CreditCardInfo
 );
 
+sub BUILD { ## no critic ( Subroutines::RequireFinalReturn )
+	my $self = shift;
+	confess 'a Stand Alone Credit should not set a request_id'
+		if $self->service->has_request_id
+		;
+}
+
 __PACKAGE__->meta->make_immutable;
 1;
 
@@ -27,7 +34,7 @@ Business::CyberSource::Request::StandAloneCredit - CyberSource Credit Request Ob
 
 =head1 VERSION
 
-version 0.005004
+version 0.006000
 
 =head1 SYNOPSIS
 
@@ -35,19 +42,27 @@ version 0.005004
 
 	my $req = Business::CyberSource::Request::StandAloneCredit->new({
 		reference_code => 'merchant reference code',
-		first_name     => 'Caleb',
-		last_name      => 'Cushing',
-		street         => 'somewhere',
-		city           => 'Houston',
-		state          => 'TX',
-		zip            => '77064',
-		country        => 'US',
-		email          => 'xenoterracide@gmail.com',
-		total          => 5.00,
-		currency       => 'USD',
-		credit_card    => '4111-1111-1111-1111',
-		cc_exp_month   => '09',
-		cc_exp_year    => '2025',
+		bill_to => {
+			first_name  => 'Caleb',
+			last_name   => 'Cushing',
+			street      => 'somewhere',
+			city        => 'Houston',
+			state       => 'TX',
+			postal_code => '77064',
+			country     => 'US',
+			email       => 'xenoterracide@gmail.com',
+		},
+		purchase_totals => {
+			total    => 5.00,
+			currency => 'USD',
+		},
+		card => {
+			account_number => '4111-1111-1111-1111',
+			expiration => {
+				month => '09',
+				year  => '2025',
+			},
+		},
 	});
 
 =head1 DESCRIPTION
