@@ -3,21 +3,24 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.005004'; # VERSION
+our $VERSION = '0.006000'; # VERSION
 
 use Moose::Role;
+use MooseX::RemoteHelper;
 use MooseX::Types::CyberSource qw( _VarcharFifty );
 
 has reference_code => (
-	required => 1,
-	is       => 'ro',
-	isa      => _VarcharFifty,
+	isa         => _VarcharFifty,
+	remote_name => 'merchantReferenceCode',
+	required    => 1,
+	is          => 'ro',
 );
 
 1;
 
 # ABSTRACT: Generic implementation of MerchantReferenceCode
 
+
 __END__
 =pod
 
@@ -27,7 +30,15 @@ Business::CyberSource::Role::MerchantReferenceCode - Generic implementation of M
 
 =head1 VERSION
 
-version 0.005004
+version 0.006000
+
+=head1 ATTRIBUTES
+
+=head2 reference_code
+
+Merchant-generated order reference or tracking number. CyberSource recommends
+that you send a unique value for each transaction so that you can perform
+meaningful searches for the transaction.
 
 =head1 BUGS
 
